@@ -144,7 +144,8 @@ class DataFrame:
             if self.has_header:
                 nrow -= 1
                 
-            command = "awk 'BEGIN{FS=\"" + self.delimiter + "\"}{if (NR>1){exit}}END{print NF}' " + self.path
+            command = "gawk -v FPAT='([^" + self.delimiter + "]*)|(\"[^\"]+\")' 'BEGIN{}{if (NR>1){exit}}END{print NF}' " + self.path
+#             print(command)
             result = os.popen(command).read()
             values = result.replace("\n","").strip()
             ncol = int(values)
@@ -170,9 +171,9 @@ class DataFrame:
 
 
     def __shape_current__(self,has_header = True):
-        command = "awk -v has_header=has_header_variable " + """'
+        command = "gawk -v FPAT='([^" + self.delimiter + "]*)|(\"[^\"]+\")' -v has_header=has_header_variable " + """'
         BEGIN {
-            FS = \"""" + self.delimiter + """\"
+            
             number_rows = 0
         }
         {
@@ -207,9 +208,9 @@ class DataFrame:
         if len(self.columns) == 0:
             if self.has_header:
                 input = self.path
-                command = "awk " + """'
+                command = "gawk -v FPAT='([^" + self.delimiter + "]*)|(\"[^\"]+\")' " + """'
             BEGIN {
-                FS = \"""" + self.delimiter + """\"
+          
             }
             {
                 if (NR == 1){
@@ -375,9 +376,9 @@ class DataFrame:
     #         os.system(command)
 
             variables = "-v has_header=\"has_header_variable\" -v output_header=\"output_header_variable\" -v min_row=\"" + str(min_row) + "\" -v max_row=\"" + str(max_row) + "\" "
-            command = "awk " + variables + """'
+            command = "gawk -v FPAT='([^" + self.delimiter + "]*)|(\"[^\"]+\")' " + variables + """'
             BEGIN {
-                FS = \"""" + self.delimiter + """\"
+
                 RS = "record_delimiter"
                 RS_new = "record_delimiter_transform"
 
@@ -462,9 +463,9 @@ class DataFrame:
             command = "echo '" + rows_str + "'>" + path_rows
             os.system(command)
             variables = "-v has_header=\"has_header_variable\" -v output_header=\"output_header_variable\" -v min_row=\"" + str(min(rows)) + "\" -v max_row=\"" + str(max(rows)) + "\" -v length_rows=\"" + str(len(rows)) + "\" "
-            command = "awk " + variables + """'
+            command = "gawk -v FPAT='([^" + self.delimiter + "]*)|(\"[^\"]+\")' " + variables + """'
             BEGIN {
-                FS = \"""" + self.delimiter + """\"
+         
                 RS = "record_delimiter"
                 RS_new = "record_delimiter_transform"
                 
@@ -563,9 +564,8 @@ class DataFrame:
         command = "echo '" + cols_str + "' | sort | xargs -I {} echo \"{}\" >" + path_cols
         os.system(command)
         variables = "-v has_header=\"has_header_variable\" -v output_header=\"output_header_variable\" -v min_col=\"" + str(min(cols)) + "\" -v max_col=\"" + str(max(cols)) + "\" "
-        command = "awk " + variables + """'
+        command = "gawk -v FPAT='([^" + self.delimiter + "]*)|(\"[^\"]+\")' " + variables + """'
         BEGIN {
-            FS = \"""" + self.delimiter + """\"
             RS = "record_delimiter"
             RS_new = "record_delimiter_transform"
             cmd = "cat """ + path_cols + """\"
@@ -672,9 +672,9 @@ class DataFrame:
 
     def get_types(self,num_rows_to_check = 1000):
         awk_command = Awk_command()
-        command = "awk " + """'
+        command = "gawk -v FPAT='([^" + self.delimiter + "]*)|(\"[^\"]+\")' " + """'
         BEGIN {
-            FS = \"""" + self.delimiter + """\"
+         
             number_rows = 0
             types[""] = "int"
         }
@@ -722,9 +722,9 @@ class DataFrame:
 
     def head(self,n=10):
         awk_command = Awk_command()
-        command = "awk " + """'
+        command = "gawk -v FPAT='([^" + self.delimiter + "]*)|(\"[^\"]+\")' " + """'
         BEGIN {
-            FS = ","
+
         }
         {
             if (NR < """ + str(n+2) + """){
@@ -751,9 +751,9 @@ class DataFrame:
 
     def __head_current__(self,n=10):
         awk_command = Awk_command()
-        command = "awk " + """'
+        command = "gawk -v FPAT='([^" + self.delimiter + "]*)|(\"[^\"]+\")' " + """'
         BEGIN {
-            FS = ","
+
         }
         {
             if (NR < """ + str(n+2) + """){
@@ -778,13 +778,13 @@ class DataFrame:
         
         condition_as_string = condition_as_string.replace(" in ["," _in_ [")
 
-        operators = [">=","<=",">","<","==","!=","~"," ","&&","\|\|","&","\|","!","(",")"]
+        operators = [">=","<=",">","<","==","!=","~"," ","&&","||","&","|","!","(",")"]
         text = "echo \"" + condition_as_string + "\" | "
         for operator in operators:
-            text = text + "awk 'BEGIN{FS = \"" + operator + "\"}{print($1);for (i=2;i<=NF;i++){if (FS!=\" \"){print (FS)};print($i)}}' | "
+            text = text + "gawk 'BEGIN{FS = \"" + operator + "\"}{print($1);for (i=2;i<=NF;i++){if (FS!=\" \"){print (FS)};print($i)}}' | "
 
         command = text
-        command = command + """awk '
+        command = command + """gawk '
         {if ($0 ~ /^[0-9]*[.][0-9]*$/)
             {
                 if ($0 ~ /^[.][0-9]*$/){
@@ -795,7 +795,7 @@ class DataFrame:
                 }
             }else{print($0)}}
         '"""
-        # print(command)
+#         print(command)
         result = os.popen(command).read()
         result = result.replace("\n\n","\n")
         result = result.replace("\n\n","\n")
@@ -845,10 +845,10 @@ class DataFrame:
 
         for i in range(len(bit_operators_and_or_not)):
             condition_as_string = condition_as_string.replace(bit_operators_and_or_not[i],awk_operators_and_or_not[i])
-
-        command = """awk '
+#         print(condition_as_string)
+        command = """gawk -v FPAT='([^""" + self.delimiter + """]*)|(\"[^\"]+\")' '
         BEGIN {
-            FS = ","
+
             column = column+1
         }
         {
@@ -865,6 +865,8 @@ class DataFrame:
         }
         END {}
         ' """
+        
+#         print(command)
         awk_command = Awk_command()
         awk_command.command = command
         awk_command.priority = 1
@@ -879,13 +881,13 @@ class DataFrame:
 
         equation = equation.replace(" in ["," _in_ [")
 
-        operators = [">=","<=",">","<","==","=","!=","~"," ","&&","\|\|","&","\|","!","(",")"]
+        operators = [">=","<=",">","<","==","=","!=","~"," ","&&","||","&","|","!","(",")"]
         text = "echo \"" + equation + "\" | "
         for operator in operators:
-            text = text + "awk 'BEGIN{FS = \"" + operator + "\"}{print($1);for (i=2;i<=NF;i++){if (FS!=\" \"){print (FS)};print($i)}}' | "
+            text = text + "gawk 'BEGIN{FS = \"" + operator + "\"}{print($1);for (i=2;i<=NF;i++){if (FS!=\" \"){print (FS)};print($i)}}' | "
 
         command = text
-        command = command + """awk '
+        command = command + """gawk '
         {if ($0 ~ /^[0-9]*[.][0-9]*$/)
             {
                 if ($0 ~ /^[.][0-9]*$/){
@@ -949,9 +951,9 @@ class DataFrame:
         equation = equation.split("=")
         column_to_modify = equation[0].strip()
         equation = equation[1].strip()
-        command = """awk '
+        command = """gawk -v FPAT='([^""" + self.delimiter + """]*)|(\"[^\"]+\")' '
         BEGIN {
-            FS = \"""" + self.delimiter + """\"
+    
             RS = "record_delimiter"
             RS_new = "record_delimiter_transform"
         }
